#[shape]Expand description
Attaches a shape literal to an item inside a #[sim_lib] module. It is
consumed by #[sim_lib]; applied on its own it leaves the item unchanged.
#[shape]Attaches a shape literal to an item inside a #[sim_lib] module. It is
consumed by #[sim_lib]; applied on its own it leaves the item unchanged.